fitzig.select: Conduct fitZIG analysis (metagenomeSeq paclage) with selected...

Description Usage Arguments

View source: R/fitzig.select.R

Description

Conduct fitZIG analysis (metagenomeSeq paclage) with selected subpopulation

Usage

1
2
3
4
5
6
7
8
fitzig.select(
  obj,
  var.select = Type,
  condition = c(3, 4),
  var.analyze = "ACPA",
  rareTrimming,
  fit.zig.settings
)

Arguments

obj

<object; input> A metagenomeSeq-class object.

var.select

<object> A variable name for selection of subpopulation.

condition

Levels in var.select variable of to be selected sub population.

var.analyze

<character> A variable name for independent variable in analysis model.

rareTrimming

<numeric> Taxa with the lesser number of subjects in which the taxa were detected are trimmed.

fit.zig.settings

<numeric> Pass to fitZig function.


mrmtshmp/ExploratoryDataAnalysis documentation built on Oct. 6, 2020, 8 a.m.