mf.lineplot: Make many boxplots on line plot from tidy ordering sheet

Description Usage Arguments

View source: R/boxplots_ordering.R

Description

Make many boxplots on line plot from tidy ordering sheet

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
mf.lineplot(
  data,
  ggdata,
  var.x,
  var.y,
  var.group,
  scale.var.y,
  ax.breaks.x,
  ax.lab.x = NULL,
  ax.lab.y = NULL,
  var.caption,
  size = 0.5,
  var.col = NA,
  plot.col = "black",
  box.col = "gray",
  str,
  str.x = NULL,
  str.y = NULL,
  .dir.output = dir.output,
  dn.surfix
)

Arguments

data

<object; input> A data frame with variables (ind, var.x, var.y, trans.y, trans.x, var.col, str, dn.surfix)

ggdata

<object; input> A object with ggplot-class

var.x

<character; proccessing>

var.y

<character; proccessing>

var.group

<character; proccessing>

size

<numeric; proccessing>

var.col

<character; proccessing>

plot.col

<character; proccessing>

box.col

<character; proccessing>

str

<character; proccessing>

dn.surfix

<character; output>


mrmtshmp/ExploratoryDataAnalysis documentation built on Oct. 6, 2020, 8 a.m.